==> dl.php?src=linea21_1_3.zip: linea21/languages/es/define.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage es
 * @author Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$l10n_links = array ('es' => array(
    					'home'=> array ('linkvalue' => 'inicio', 'accesskey' => '1', 'title' => 'inicio', 'desc'=>'Volver a página de inicio', 'alias'=> false, 'template'=>'home'),
    					'project'=> array ('linkvalue' => 'proyecto', 'accesskey' => 'a', 'title' => 'proyectos', 'desc'=>'Proyectos de desarrollo sostenible', 'alias'=> false, 'template'=>'publication'),
						'project-archives'=> array ('linkvalue' => 'proyecto-archivos', 'title' => 'proyecto', 'desc'=>'Proyectos de desarrollo sostenible', 'alias'=> 'project', 'template'=>'publication'), 
    					'news'=> array ('linkvalue' => 'noticia', 'accesskey' => 'n', 'title' => 'noticias', 'desc'=>'Noticias de su municipio', 'alias'=> false, 'template'=>'publication'), 
    					'news-archives'=> array ('linkvalue' => 'noticia-archivos', 'title' => 'noticias - archivos', 'desc'=>'Archivos de noticias de su municipio', 'alias'=> 'news', 'template'=>'publication'),
    					'report'=> array ('linkvalue' => 'informe', 'title' => 'Informes del grupo de trabajo', 'desc'=>'Ver el informe del grupo de trabajo', 'alias'=> 'workgroup', 'template'=>'publication'),
    					'report-part'=> array ('linkvalue' => 'informe-apartado', 'title' => 'Detalles del informe del grupo de trabajo', 'desc'=>'Ver apartado del informe del grupo de trabajo', 'alias'=> 'workgroup', 'template'=>'publication'),
    					'directory'=> array ('linkvalue' => 'directorio', 'accesskey' => 'y', 'title' => 'Directorio de Organizaciones', 'desc'=>'Directorio de organizaciones de desarrollo sostenible', 'alias'=> false, 'template'=>'yellowpages'),
    					'directory-detail'=> array ('linkvalue' => 'directorio-detalle', 'title' => 'Directorio de Organizaciones', 'desc'=>'Directorio de organizaciones de desarrollo sostenible', 'alias'=> 'directory', 'template'=>'yellowpages'),
    					'directory-add'=> array ('linkvalue' => 'directorio-anadir', 'title' => 'Directorio de Organizaciones', 'desc'=>'Directorio de organizaciones de desarrollo sostenible', 'alias'=> 'directory', 'template'=>'yellowpages'),
    					'workgroup'=> array ('linkvalue' => 'grupo-de-trabajo', 'accesskey' => 'w', 'title' => 'Grupos de Trabajo', 'desc'=>'Acceso y participación en grupos de trabajo', 'alias'=> false, 'template'=>'workshop'), 
    					'subscribe-workgroup'=> array ('linkvalue' => 'subscripcion-grupo-de-trabajo', 'title' => 'Subscripcion al grupo de trabajo', 'desc'=>'Subscribirse a un grupo de trabajo', 'alias'=> 'workgroup', 'template'=>'workshop'), 
    					'calendar'=> array ('linkvalue' => 'calendario', 'title' => 'Calendario del grupo de trabajo', 'desc'=>'Calendario del grupo de trabajo', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'topic-list'=> array ('linkvalue' => 'temas-lista', 'title' => 'Foro del grupo de trabajo', 'desc'=>'Foro del grupo de trabajo', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'topic'=> array ('linkvalue' => 'tema', 'title' => 'tema', 'desc'=>'Temas en el foro del grupo de trabajo', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'post-update'=> array ('linkvalue' => 'editar-mensaje', 'title' => 'Editar mensaje', 'desc'=>'Editar mensaje del foro', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'topic-add'=> array ('linkvalue' => 'anadir-tema', 'title' => 'Añadir nuevo tema', 'desc'=>'Añadir nuevo tema', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'post-add'=> array ('linkvalue' => 'anadir-mensaje', 'title' => 'Añadir nuevo mensaje', 'desc'=>'Añadir nuevo mensaje', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'publication'=> array ('linkvalue' => 'publicacion', 'accesskey' => 'p', 'title' => 'publicaciones', 'desc'=>'Publicaciones temáticas', 'alias'=> false, 'template'=>'publication'),
    					'publication-archives'=> array ('linkvalue' => 'publicacion-archivos', 'title' => 'publicaciones - archivos', 'desc'=>'Archivos de publicaciones temáticas', 'alias'=> 'publication', 'template'=>'publication'),
    					'publication-part'=> array ('linkvalue' => 'publicacion-apartados', 'title' => 'publicaciones - apartados', 'desc'=>'Publicaciones tematicas en detalle', 'alias'=> 'publication', 'template'=>'publication'),
    					'dashboard'=> array ('linkvalue' => 'panel-de-indicadores', 'accesskey' => 'd', 'title' => 'Panel IDS', 'desc'=>'Panel de Indicadores : seguimiento de indicadores a tiempo real', 'alias'=> false, 'template'=>'dashboard'),  
                        'dashboard-rules'=> array ('linkvalue' => 'panel-de-indicadores-reglas', 'title' => 'Reglas del indicador', 'desc'=>'Reglas del indicador', 'alias'=> 'dashboard', 'template'=>'dashboard'),  
                        'dashboard-assessment'=> array ('linkvalue' => 'panel-de-indicadores-evaluacion', 'title' => 'Evaluación del indicador', 'desc'=>'Evaluación del indicador', 'alias'=> 'dashboard', 'template'=>'dashboard'),  
                        'dashboard-provider'=> array ('linkvalue' => 'panel-de-indicadores-proveedor', 'title' => 'Proveedor del indicador', 'desc'=>'Proveedor del indicador', 'alias'=> 'dashboard', 'template'=>'dashboard'),
    					'user-prefs'=> array ('linkvalue' => 'usuario-preferencias', 'accesskey' => 'u', 'title' => 'preferencias del usuario', 'desc'=>'Acceso a preferencias de usuario', 'alias'=> false, 'template'=>'user'),
    					'logout'=> array ('linkvalue' => 'cerrar-sesion', 'accesskey' => 'l', 'title' => 'cerrar sesión', 'desc'=>'cerrar sesión', 'alias'=> false, 'template'=>'user'),
    					'user-registration'=> array ('linkvalue' => 'usuario-registro', 'accesskey' => 'c', 'title' => 'registrarse', 'desc'=>'Registrarse, crear una cuenta', 'alias'=> 'user-prefs', 'template'=>'user'),
    					'user-profile'=> array ('linkvalue' => 'usuario-perfil', 'title' => 'perfil de usuario', 'desc'=>'Ver perfil de usuario', 'alias'=> 'user-prefs', 'template'=>'user'),
    					'search'=> array ('linkvalue' => 'buscar', 'accesskey' => '4', 'title' => 'búsqueda avanzada', 'desc'=>'Relizar búsqueda avanzada', 'alias'=> false, 'template'=>'search'),
    					'search-result'=> array ('linkvalue' => 'buscar-resultados', 'title' => 'resultados de búsqueda', 'desc'=>'Resultados de la búsqueda', 'alias'=> 'search', 'template'=>'search'),
    					'accessibility'=> array ('linkvalue' => 'accesibilidad', 'accesskey' => '1', 'title' => 'política de acceso de Linea21', 'desc'=>'Política de acceso de Linea21', 'alias'=> false, 'template'=>'accessibility'),
    					'report-all'=> array ('linkvalue' => 'todos-los-informes', 'title' => 'todos los informes del grupo de trabajo', 'desc'=>'Informes del grupo de trabajo', 'alias'=> 'workgroup', 'template'=>'workshop'),  
                        'user-all'=> array ('linkvalue' => 'todos-los-usuarios', 'title' => 'todos los usuarios del grupo de trabajo', 'desc'=>'Usuarios del grupo de trabajo', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'subscribe-newsletter'=> array ('linkvalue' => 'subscripcion-boletin', 'title' => 'subscripción al boletín', 'desc'=>'Subscribirse al boletín', 'alias'=> false, 'template'=>'message'),
    					'css-switch'=> array ('linkvalue' => 'cambiar-estilo-css', 'title' => 'cambiar CSS', 'desc'=>'cambiar estilo y CSS', 'alias'=> false, 'template'=>'message')
));

$l10n_filters = array ('es' => array(
                            'level' => array('linkvalue' => 'nivel', 'name' => 'nivel', 'desc'=>'mostrar por nivel', 'active' => 0),
    						'theme' => array('linkvalue' => 'área temática', 'name' => 'área temática', 'desc'=>'mostrar por área', 'active' => 0),
                        	'priority' => array('linkvalue' => 'prioridad', 'name' => 'prioridad', 'desc'=>'mostrar por prioridad', 'active' => 0),
    						'scale' => array('linkvalue' => 'escala', 'name' => 'escala', 'desc'=>'mostrar por escala', 'active' => 0),
                            'alpha' => array('linkvalue' => 'alfabético', 'name' => 'alfabético', 'desc'=>'mostrar por orden alfabético', 'active' => 0)
));
?>

==> dl.php?src=linea21_1_4.zip: linea21/languages/es/define.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage es
 * @author Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

$culture = array( 'es' => array( 'Language' => 'Español'));

$l10n_links = array ('es' => array(
    					'home'=> array ('linkvalue' => 'inicio', 'accesskey' => '1', 'title' => 'inicio', 'desc'=>'Volver a página de inicio', 'alias'=> false, 'template'=>'home'),
    					'project'=> array ('linkvalue' => 'proyecto', 'accesskey' => 'a', 'title' => 'proyectos', 'desc'=>'Proyectos de desarrollo sostenible', 'alias'=> false, 'template'=>'publication'),
						'project-archives'=> array ('linkvalue' => 'proyecto-archivos', 'title' => 'proyecto', 'desc'=>'Proyectos de desarrollo sostenible', 'alias'=> 'project', 'template'=>'publication'),
    					'news'=> array ('linkvalue' => 'noticia', 'accesskey' => 'n', 'title' => 'noticias', 'desc'=>'Noticias', 'alias'=> false, 'template'=>'publication'),
    					'news-archives'=> array ('linkvalue' => 'noticia-archivos', 'title' => 'noticias - archivos', 'desc'=>'Archivos de noticias', 'alias'=> 'news', 'template'=>'publication'),
    					'report'=> array ('linkvalue' => 'informe', 'title' => 'Informes del grupo de trabajo', 'desc'=>'Ver el informe del grupo de trabajo', 'alias'=> 'workgroup', 'template'=>'publication'),
    					'report-part'=> array ('linkvalue' => 'informe-apartado', 'title' => 'Detalles del informe del grupo de trabajo', 'desc'=>'Ver apartado del informe del grupo de trabajo', 'alias'=> 'workgroup', 'template'=>'publication'),
    					'directory'=> array ('linkvalue' => 'directorio', 'accesskey' => 'y', 'title' => 'Directorio de Organizaciones', 'desc'=>'Directorio de organizaciones de desarrollo sostenible', 'alias'=> false, 'template'=>'yellowpages'),
    					'directory-detail'=> array ('linkvalue' => 'directorio-detalle', 'title' => 'Directorio de Organizaciones', 'desc'=>'Directorio de organizaciones de desarrollo sostenible', 'alias'=> 'directory', 'template'=>'yellowpages'),
    					'directory-add'=> array ('linkvalue' => 'directorio-anadir', 'title' => 'Directorio de Organizaciones', 'desc'=>'Directorio de organizaciones de desarrollo sostenible', 'alias'=> 'directory', 'template'=>'yellowpages'),
    					'workgroup'=> array ('linkvalue' => 'grupo-de-trabajo', 'accesskey' => 'w', 'title' => 'Grupos de Trabajo', 'desc'=>'Acceso y participación en grupos de trabajo', 'alias'=> false, 'template'=>'workshop'),
    					'workgroup-subscription'=> array ('linkvalue' => 'subscripcion-grupo-de-trabajo',  'accesskey' => 's', 'title' => 'Subscripcion al grupo de trabajo', 'desc'=>'Subscribirse a un grupo de trabajo', 'alias'=> false, 'template'=>'wg-subscription'),
    					'files'=> array ('linkvalue' => 'carpetas', 'title' => 'Acceso a las carpetas', 'desc'=>'Acceso a las carpetas', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'calendar'=> array ('linkvalue' => 'calendario', 'title' => 'Calendario del grupo de trabajo', 'desc'=>'Calendario del grupo de trabajo', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'topic-list'=> array ('linkvalue' => 'temas-lista', 'title' => 'Foro del grupo de trabajo', 'desc'=>'Foro del grupo de trabajo', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'topic'=> array ('linkvalue' => 'tema', 'title' => 'tema', 'desc'=>'Temas en el foro del grupo de trabajo', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'post-update'=> array ('linkvalue' => 'editar-mensaje', 'title' => 'Editar mensaje', 'desc'=>'Editar mensaje del foro', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'topic-add'=> array ('linkvalue' => 'anadir-tema', 'title' => 'Añadir nuevo tema', 'desc'=>'Añadir nuevo tema', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'post-add'=> array ('linkvalue' => 'anadir-mensaje', 'title' => 'Añadir nuevo mensaje', 'desc'=>'Añadir nuevo mensaje', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'publication'=> array ('linkvalue' => 'publicacion', 'accesskey' => 'p', 'title' => 'publicaciones', 'desc'=>'Publicaciones temáticas', 'alias'=> false, 'template'=>'publication'),
    					'publication-archives'=> array ('linkvalue' => 'publicacion-archivos', 'title' => 'publicaciones - archivos', 'desc'=>'Archivos de publicaciones temáticas', 'alias'=> 'publication', 'template'=>'publication'),
    					'publication-part'=> array ('linkvalue' => 'publicacion-apartados', 'title' => 'publicaciones - apartados', 'desc'=>'Publicaciones tematicas en detalle', 'alias'=> 'publication', 'template'=>'publication'),
    					'dashboard'=> array ('linkvalue' => 'panel-de-indicadores', 'accesskey' => 'd', 'title' => 'Panel IDS', 'desc'=>'Panel de Indicadores : seguimiento de indicadores a tiempo real', 'alias'=> false, 'template'=>'dashboard'),
                        'dashboard-rules'=> array ('linkvalue' => 'panel-de-indicadores-reglas', 'title' => 'Reglas del indicador', 'desc'=>'Reglas del indicador', 'alias'=> 'dashboard', 'template'=>'dashboard'),
                        'dashboard-assessment'=> array ('linkvalue' => 'panel-de-indicadores-evaluacion', 'title' => 'Evaluación del indicador', 'desc'=>'Evaluación del indicador', 'alias'=> 'dashboard', 'template'=>'dashboard'),
                        'dashboard-provider'=> array ('linkvalue' => 'panel-de-indicadores-proveedor', 'title' => 'Proveedor del indicador', 'desc'=>'Proveedor del indicador', 'alias'=> 'dashboard', 'template'=>'dashboard'),
    					'user-prefs'=> array ('linkvalue' => 'usuario-preferencias', 'accesskey' => 'u', 'title' => 'preferencias del usuario', 'desc'=>'Acceso a preferencias de usuario', 'alias'=> false, 'template'=>'user'),
    					'logout'=> array ('linkvalue' => 'cerrar-sesion', 'accesskey' => 'l', 'title' => 'cerrar sesión', 'desc'=>'cerrar sesión', 'alias'=> false, 'template'=>'user'),
    					'user-registration'=> array ('linkvalue' => 'usuario-registro', 'accesskey' => 'c', 'title' => 'registrarse', 'desc'=>'Registrarse, crear una cuenta', 'alias'=> 'user-prefs', 'template'=>'user'),
    					'user-profile'=> array ('linkvalue' => 'usuario-perfil', 'title' => 'perfil de usuario', 'desc'=>'Ver perfil de usuario', 'alias'=> 'user-prefs', 'template'=>'user'),
    					'forgot-password'=> array ('linkvalue' => 'forgot-password', 'title' => 'Forgot your password?', 'desc'=>'Change your password', 'alias'=> 'user-prefs', 'template'=>'user'), // @todo translation
    					'search'=> array ('linkvalue' => 'buscar', 'accesskey' => '4', 'title' => 'búsqueda avanzada', 'desc'=>'Relizar búsqueda avanzada', 'alias'=> false, 'template'=>'search'),
    					'search-result'=> array ('linkvalue' => 'buscar-resultados', 'title' => 'resultados de búsqueda', 'desc'=>'Resultados de la búsqueda', 'alias'=> 'search', 'template'=>'search'),
    					'accessibility'=> array ('linkvalue' => 'accesibilidad', 'accesskey' => '1', 'title' => 'política de acceso de Linea21', 'desc'=>'Política de acceso de Linea21', 'alias'=> false, 'template'=>'accessibility'),
    					'report-all'=> array ('linkvalue' => 'todos-los-informes', 'title' => 'todos los informes del grupo de trabajo', 'desc'=>'Informes del grupo de trabajo', 'alias'=> 'workgroup', 'template'=>'workshop'),
                        'user-all'=> array ('linkvalue' => 'todos-los-usuarios', 'title' => 'todos los usuarios del grupo de trabajo', 'desc'=>'Usuarios del grupo de trabajo', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'subscribe-newsletter'=> array ('linkvalue' => 'subscripcion-boletin', 'title' => 'subscripción al boletín', 'desc'=>'Subscribirse al boletín', 'alias'=> false, 'template'=>'message'),
    					'css-switch'=> array ('linkvalue' => 'cambiar-estilo-css', 'title' => 'cambiar CSS', 'desc'=>'cambiar estilo y CSS', 'alias'=> false, 'template'=>'message'),
                        'contact'=> array ('linkvalue' => 'contacto', 'accesskey' => 'z', 'title' => 'contacto', 'desc'=>'póngase en contacto con', 'alias'=> false, 'template'=>'message')
));

$l10n_filters = array ('es' => array(
                            'level' => array('linkvalue' => 'nivel', 'name' => 'nivel', 'desc'=>'mostrar por nivel', 'active' => 0),
    						'theme' => array('linkvalue' => 'área temática', 'name' => 'área temática', 'desc'=>'mostrar por área', 'active' => 0),
                        	'priority' => array('linkvalue' => 'prioridad', 'name' => 'prioridad', 'desc'=>'mostrar por prioridad', 'active' => 0),
    						'scale' => array('linkvalue' => 'escala', 'name' => 'escala', 'desc'=>'mostrar por escala', 'active' => 0),
                            'alpha' => array('linkvalue' => 'alfabético', 'name' => 'alfabético', 'desc'=>'mostrar por orden alfabético', 'active' => 0)
));
?>
